import sys
sys.__stdout__.write("Paraview has been started\n")
sys.__stdout__.flush()
# Imports.
from paraview.simple import *

# Disable automatic camera reset on 'Show'
paraview.simple._DisableFirstRenderCameraReset()

# Read data with EnSight Reader.
simulationData = EnSightReader(CaseFileName='C:/Users/User/AppData/Local/Temp/cenos/~new-cenos-case/results/resFile.0.case')
RenameSource('Simulation Data', simulationData)

# Update animation scene based on data timesteps.
animationScene1 = GetAnimationScene()
animationScene1.UpdateAnimationUsingDataTimeSteps()
animationScene1.GoToLast()

# Get active view.
renderView1 = GetActiveViewOrCreate('RenderView')

# Show data in view.
simulationDataDisplay = Show(simulationData, renderView1)

# Find indices of primary and secondary blocks. (NB: simulationData should be initialized in renderView.)
primaryBlockNames = ['workpiece']
secondaryBlockNames = ['winding_0','winding_1','winding_2','winding_3','winding_4','winding_5']
primaryBlocks = []
secondaryBlocks = []
compositeData = simulationData.GetDataInformation().GetCompositeDataInformation()
blockCount = compositeData.GetNumberOfChildren()
for i in range(blockCount):
    name = compositeData.GetName(i)
    if name in primaryBlockNames:
        primaryBlocks.append(i+1)
    if name in secondaryBlockNames:
        secondaryBlocks.append(i+1)
# Set interaction mode.
renderView1.InteractionMode = '2D'

# Set primary field.
ColorBy(simulationDataDisplay, ('POINTS', 'Temperature_T_[C]'))

# Hide.
Hide(simulationData, renderView1)

#
# WORKPIECE
#

# Create a new 'Extract Block'.
extractBlock11 = ExtractBlock(Input=simulationData)
RenameSource('Workpiece', extractBlock11)

# Set visible blocks.
extractBlock11.BlockIndices = primaryBlocks

# Show extracted block.
extractBlock11Display = Show(extractBlock11, renderView1)

# Set primary field.
ColorBy(extractBlock11Display, ('POINTS', 'Temperature_T_[C]'))

# Rescale color and/or opacity maps.
extractBlock11Display.RescaleTransferFunctionToDataRange(True, False)

# Show legend.
extractBlock11Display.SetScalarBarVisibility(renderView1, True)

# Get color and opacity transfer functions.
primaryFieldLUT = GetColorTransferFunction('Temperature_T_[C]')
primaryFieldPWF = GetOpacityTransferFunction('Temperature_T_[C]')

# Rename.
primaryFieldLUTColorBar1 = GetScalarBar(primaryFieldLUT, renderView1)
primaryFieldLUTColorBar1.Title = 'Temperature T ['

#
# INDUCTOR
#

# Create a new 'Extract Block'.
extractBlock12 = ExtractBlock(Input=simulationData)
RenameSource('Inductor', extractBlock12)

# Set visible blocks.
extractBlock12.BlockIndices = secondaryBlocks

# Show extracted block.
extractBlock12Display = Show(extractBlock12, renderView1)

# Set solid color.
ColorBy(extractBlock12Display, ('POINTS', ''))
extractBlock12Display.DiffuseColor = [0.72, 0.45, 0.2]

# INDUCTOR END
###

# Position camera.
if False:
    renderView1.CameraFocalPoint = [0, 0, 0]
    renderView1.CameraViewUp = [-0.1, 0, 1]
    renderView1.CameraPosition =  [490, -98, 204]

# Update view. Reset to fit data. Render.
renderView1.Update()
renderView1.ResetCamera()
Render()
# Split layout.
layout1 = GetLayout()
layout1.SplitHorizontal(0, 0.5)

# Create the 2nd view.
renderView2 = CreateView('RenderView')
layout1.AssignView(2, renderView2)

# Activate source.
SetActiveView(renderView2)
SetActiveSource(simulationData)

# Set primary field.
ColorBy(simulationDataDisplay, ('POINTS', 'Temperature_T_[C]'))

# Hide.
Hide(simulationData, renderView2)

#
# WORKPIECE
#

# Create a new Cenos filter.
create3Dfrom2D1 = Create3Dfrom2D(Input=simulationData)
RenameSource('Workpiece 3D', create3Dfrom2D1)

# Set parameters.
create3Dfrom2D1.Angle = 240.0
create3Dfrom2D1.BlockIndices = primaryBlocks
create3Dfrom2D1.Resolution = 100

# Activate.
SetActiveSource(create3Dfrom2D1)

# Show extracted block.
create3Dfrom2D1Display = Show(create3Dfrom2D1, renderView2)

# Set primary field.
ColorBy(create3Dfrom2D1Display, ('POINTS', 'Temperature_T_[C]'))

# Rescale color and/or opacity maps.
create3Dfrom2D1Display.RescaleTransferFunctionToDataRange(True, False)

# Show legend.
create3Dfrom2D1Display.SetScalarBarVisibility(renderView2, True)

# Get color and opacity transfer functions.
primaryFieldLUT = GetColorTransferFunction('Temperature_T_[C]')
primaryFieldPWF = GetOpacityTransferFunction('Temperature_T_[C]')

# Rename.
primaryFieldLUTColorBar2 = GetScalarBar(primaryFieldLUT, renderView2)
primaryFieldLUTColorBar2.Title = 'Temperature T ['

#
# INDUCTOR
#

# Create a new Cenos filter.
create3Dfrom2D2 = Create3Dfrom2D(Input=simulationData)
RenameSource('Inductor 3D', create3Dfrom2D2)

# Set parameters.
create3Dfrom2D2.Angle = 240.0
create3Dfrom2D2.BlockIndices = secondaryBlocks
create3Dfrom2D2.Resolution = 100

# Activate.
SetActiveSource(create3Dfrom2D2)

# Show extracted block.
create3Dfrom2D2Display = Show(create3Dfrom2D2, renderView2)

# Set solid color.
ColorBy(create3Dfrom2D2Display, ('POINTS', ''))
create3Dfrom2D2Display.DiffuseColor = [0.72, 0.45, 0.2]

# Position camera.
# camera2 = GetActiveCamera()
# camera2.SetFocalPoint(0,0,0)
# camera2.SetPosition(0,-1,0)
# camera2.SetViewUp(0,0,1)

# Update view. Reset to fit data. Render.
renderView2.Update()
renderView2.ResetCamera()
Render()
